#!/bin/bash

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

if [ -z $SW_HOME ]; then
  export SW_HOME=${DIR}
fi

appdir=~/.local/share/applications 
icondir=~/.local/share/icons 

# Install icons
if [ -d $icondir ]; then
    mkdir -p $icondir/hicolor/48x48/apps/
    cp $SW_HOME/share/icons/hicolor/48x48/apps/*.png $icondir/hicolor/48x48/apps/
fi

# Create desktop environment links
if [ -d $appdir ]; then
    if [ -x $appdir/silentwings-simulator.desktop ]; then
        rm -f $appdir/silentwings-simulator.desktop
    fi
    cat $SW_HOME/share/applications/silentwings-simulator.desktop.in | sed 's|--SW_HOME--|'$SW_HOME'|' > $appdir/silentwings-simulator.desktop
fi    

if [ -d $appdir ]; then
    if [ -x $appdir/silentwings-viewer.desktop ]; then
        rm -f $appdir/silentwings-viewer.desktop
    fi
    cat $SW_HOME/share/applications/silentwings-viewer.desktop.in | sed 's|--SW_HOME--|'$SW_HOME'|' > $appdir/silentwings-viewer.desktop
fi    

# Check for required packages
if which dpkg-query > /dev/null; then 
    # Debian-like system:
    pkg=freeglut3:i386 
    if [ $(dpkg-query -W -f='${Status}' $pkg 2>/dev/null | grep -c "ok installed") -eq 0 ]; then
        read -p "32-bits OpenGL packages ($pkg) not found. Install now? (y/n) " -n 1 -r
        if [[ $REPLY =~ ^[Yy]$ ]]
        then
            sudo apt-get install $pkg
        else
            echo "You need 32-bit OpenGL packages ($pkg) to run Silent Wings, aborting."
        fi
    else 
        echo "Found 32-bits OpenGL packages ($pkg)."
    fi
fi

# Check if we are still missing some libraries
export LD_LIBRARY_PATH=${SW_HOME}/lib

missing_sw_gui_libs=`ldd $SW_HOME/bin/sw_gui | grep "not found"`
if [ ! -z "$missing_sw_gui_libs" ]; then
  cat << !
ERROR!
  
You are missing some important system libraries.
See the following list for details:

$missing_sw_gui_libs

Check your linux distribution and ensure that at you have 32-bits system libraries and 32-bits OpenGL libraries installed.

Please contact support@silentwings.no if you have any questions about this error message.
!
  exit 1
fi

missing_swings_libs=`ldd $SW_HOME/bin/swings | grep "not found"`
if [ ! -z "$missing_swings_libs" ]; then
    cat << !
ERROR!
    
You are missing some important system libraries.
See the following list for details:

$missing_swings_libs

Check your linux distribution and ensure that at you have 32-bits system libraries and 32-bits OpenGL libraries installed.
 
Please contact support@silentwings.no if you have any questions about this error message.
!
  exit 1
fi

cat << ! 
Silent Wings installed OK. 

Start it from the desktop menu or by running the supplied 'SilentWings' and 'SilentWingsViewer' shell scripts. 

Happy flying!
!
